@@ -1,5 +1,5 @@
 from django.apps import AppConfig
 
 
-class WebauthnConfig(AppConfig):
+class GitHubAuthConfig(AppConfig):
     name = "django_rest_github_oauth"
